@@ -1,41 +1,41 @@
 context("by_groups")
-# library(data.table)
+
 data(iris)
 expect_error(by_groups(iris, "Species"))
 expect_error(by_groups(iris, "Species", mean, b ~ sum(Sepal.Width)))
 expect_error(by_groups(iris, "Species", mean, sum))
 expect_error(by_groups(iris, "species", mean))
-expect_identical(by_groups(iris, Species, mean), 
+expect_equal(by_groups(iris, Species, mean), 
                  aggregate( . ~ Species , data = iris, FUN = mean))
 
 
-expect_identical(by_groups(iris, fixed("Species"), mean), 
+expect_equal(by_groups(iris, fixed("Species"), mean), 
                  aggregate( . ~ Species , data = iris, FUN = mean))
 
 var_name = "Species"
-expect_identical(by_groups(iris, fixed(var_name), mean), 
+expect_equal(by_groups(iris, fixed(var_name), mean), 
                  aggregate( . ~ Species , data = iris, FUN = mean))
 
-expect_identical(by_groups(iris, ..$var_name, mean), 
+expect_equal(by_groups(iris, ..$var_name, mean), 
                  aggregate( . ~ Species , data = iris, FUN = mean))
 
 
-expect_identical(by_groups(iris, ..[(var_name)], mean), 
+expect_equal(by_groups(iris, ..[(var_name)], mean), 
                  aggregate( . ~ Species , data = iris, FUN = mean))
 
-expect_identical(by_groups(iris[,-5], mean), as.data.frame(t(colMeans(iris[,-5]))))
-expect_identical(by_groups(iris[,-5], character(0), mean), as.data.frame(t(colMeans(iris[,-5]))))
+expect_equal(by_groups(iris[,-5], mean), as.data.frame(t(colMeans(iris[,-5]))))
+expect_equal(by_groups(iris[,-5], character(0), mean), as.data.frame(t(colMeans(iris[,-5]))))
 alpha = 3
-expect_identical(by_groups(iris, Species, function(x){mean(x)}),
+expect_equal(by_groups(iris, Species, function(x){mean(x)}),
                  aggregate( . ~ Species , data = iris, FUN = function(x){mean(x)}))
 
-expect_identical(by_groups(iris, Species,  ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
+expect_equal(by_groups(iris, Species,  ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
                  as.data.frame(data.table::data.table(iris)[, list("mean(Sepal.Width)" = mean(Sepal.Width), "sum(Sepal.Length)" = sum(Sepal.Length)), by = "Species"]))
 
-expect_identical(by_groups(iris, Species,  mean_width ~ mean(Sepal.Width),sum_length ~ sum(Sepal.Length)),
+expect_equal(by_groups(iris, Species,  mean_width ~ mean(Sepal.Width),sum_length ~ sum(Sepal.Length)),
                  as.data.frame(data.table::data.table(iris)[, list(mean_width = mean(Sepal.Width), sum_length = sum(Sepal.Length)), by = "Species"]))
 
-expect_identical(
+expect_equal(
     by_groups(as.list(iris), Species,  mean_width ~ mean(Sepal.Width),sum_length ~ sum(Sepal.Length)),
                  as.data.frame(data.table::data.table(iris)[, list(mean_width = mean(Sepal.Width), sum_length = sum(Sepal.Length)), by = "Species"]))
 
@@ -44,20 +44,20 @@ expect_identical(
 #                  as.data.frame(data.table(iris)[, list(mean_width = alpha*mean(Sepal.Width), sum_length = alpha*sum(Sepal.Length)), by = "Species"]))
 
 
-expect_identical(by_groups(iris,   ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
+expect_equal(by_groups(iris,   ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
                  as.data.frame(data.table::data.table(iris)[, list("mean(Sepal.Width)" = mean(Sepal.Width), "sum(Sepal.Length)" = sum(Sepal.Length))]))
 
-expect_identical(by_groups(iris,  mean_width ~ mean(Sepal.Width), sum_length ~ sum(Sepal.Length)),
+expect_equal(by_groups(iris,  mean_width ~ mean(Sepal.Width), sum_length ~ sum(Sepal.Length)),
                  as.data.frame(data.table::data.table(iris)[, list(mean_width = mean(Sepal.Width), sum_length = sum(Sepal.Length))]))
 
 
 data(mtcars)
 dt_mtcars = data.table::data.table(mtcars)
 # setkey(dt_mtcars, am, vs)
-expect_identical(by_groups(mtcars, am, vs,  ~ mean(hp), ~ sum(mpg)),
+expect_equal(by_groups(mtcars, am, vs,  ~ mean(hp), ~ sum(mpg)),
                  as.data.frame(dt_mtcars[, list("mean(hp)" = mean(hp), "sum(mpg)" = sum(mpg)), by = "am,vs"]))
 
-expect_identical(by_groups(mtcars, am, vs,  hp ~ mean(hp), mpg ~ sum(mpg)),
+expect_equal(by_groups(mtcars, am, vs,  hp ~ mean(hp), mpg ~ sum(mpg)),
                  as.data.frame(dt_mtcars[, list(hp = mean(hp), mpg = sum(mpg)), by = "am,vs"]))
 
 expect_equal(by_groups(mtcars, am, vs,  mean),
@@ -78,21 +78,21 @@ expect_equal(by_groups(dt_iris, Species, function(x){mean(x)}),
              data.table::as.data.table(aggregate( . ~ Species , data = iris, FUN = function(x){mean(x)})))
 
 # setkey(dt_iris, Species, verbose = FALSE)
-expect_identical(by_groups(dt_iris, Species,  ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
+expect_equal(by_groups(dt_iris, Species,  ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
                  (dt_iris[, list("mean(Sepal.Width)" = mean(Sepal.Width), "sum(Sepal.Length)" = sum(Sepal.Length)), by = "Species"]))
 
-expect_identical(by_groups(dt_iris, Species,  mean_width ~ mean(Sepal.Width),sum_length ~ sum(Sepal.Length)),
+expect_equal(by_groups(dt_iris, Species,  mean_width ~ mean(Sepal.Width),sum_length ~ sum(Sepal.Length)),
                  (dt_iris[, list(mean_width = mean(Sepal.Width), sum_length = sum(Sepal.Length)), by = "Species"]))
 
-expect_identical(by_groups(dt_iris,   ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
+expect_equal(by_groups(dt_iris,   ~ mean(Sepal.Width), ~ sum(Sepal.Length)),
                  (dt_iris[, list("mean(Sepal.Width)" = mean(Sepal.Width), "sum(Sepal.Length)" = sum(Sepal.Length))]))
 
-expect_identical(by_groups(dt_iris,  mean_width ~ mean(Sepal.Width), sum_length ~ sum(Sepal.Length)),
+expect_equal(by_groups(dt_iris,  mean_width ~ mean(Sepal.Width), sum_length ~ sum(Sepal.Length)),
                  (dt_iris[, list(mean_width = mean(Sepal.Width), sum_length = sum(Sepal.Length))]))
 
 dt_iris$Species = NULL
 
-expect_identical(by_groups(dt_iris, mean), data.table::as.data.table(t(colMeans(iris[,-5]))))
+expect_equal(by_groups(dt_iris, mean), data.table::as.data.table(t(colMeans(iris[,-5]))))
 
 context("by_groups variables")
 
@@ -101,14 +101,14 @@ dt_mtcars = data.table::data.table(mtcars)
 # setkey(dt_mtcars, am, vs)
 group_var = c( "am", "vs")
 expect_error(by_groups(mtcars, group_var,  ~ mean(hp), ~ sum(mpg)))
-expect_identical(by_groups(mtcars, (group_var),  ~ mean(hp), ~ sum(mpg)),
+expect_equal(by_groups(mtcars, (group_var),  ~ mean(hp), ~ sum(mpg)),
                  as.data.frame(dt_mtcars[, list("mean(hp)" = mean(hp), "sum(mpg)" = sum(mpg)), by = "am,vs"]))
 
 formulas_var = c( ~ mean(hp), ~ sum(mpg))
-expect_identical(by_groups(mtcars, (formulas_var), "am", "vs"),
+expect_equal(by_groups(mtcars, (formulas_var), "am", "vs"),
                  as.data.frame(dt_mtcars[, list("mean(hp)" = mean(hp), "sum(mpg)" = sum(mpg)), by = "am,vs"]))
 
-expect_identical(by_groups(mtcars, (group_var), (formulas_var)),
+expect_equal(by_groups(mtcars, (group_var), (formulas_var)),
                  as.data.frame(dt_mtcars[, list("mean(hp)" = mean(hp), "sum(mpg)" = sum(mpg)), by = "am,vs"]))
 
 
@@ -163,9 +163,9 @@ expect_identical(
 context("by_groups special")
 data(iris)
 
-expect_identical(by_groups(iris[,-5], character(0), mean), as.data.frame(t(colMeans(iris[,-5]))))
+expect_equal(by_groups(iris[,-5], character(0), mean), as.data.frame(t(colMeans(iris[,-5]))))
 
-expect_identical(by_groups(iris, Species, function(x){mean(x)}),
+expect_equal(by_groups(iris, Species, function(x){mean(x)}),
                  aggregate( . ~ Species , data = iris, FUN = function(x){mean(x)}))
 
 
