@@ -30,7 +30,7 @@ expect_equal_to_reference(
                              fun = w_mean, 
                              row_vars = am
     )
-    ,"rds/table_summary_df0.rds"
+    ,"rds/table_summary_df0.rds",  update = FALSE
 )
 
 # test for empty rowlabels
@@ -41,7 +41,7 @@ expect_equal_to_reference(
                              fun = function(x) {res = colMeans(x, na.rm = TRUE); unname(res)}, 
                              row_vars = am
     )
-    ,"rds/table_summary_df0rowlabels.rds"
+    ,"rds/table_summary_df0rowlabels.rds",  update = FALSE
 )
 
 expect_error(
@@ -85,7 +85,7 @@ expect_equal_to_reference(
                                    fun = colMeans, 
                                    row_vars = am
     )
-    ,"rds/table_summary_df0_colMeans.rds"
+    ,"rds/table_summary_df0_colMeans.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
@@ -94,7 +94,7 @@ expect_equal_to_reference(
                                    fun = function(x) numeric(0), 
                                    row_vars = am
     )
-    ,"rds/table_summary_df0empty.rds"
+    ,"rds/table_summary_df0empty.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
@@ -103,13 +103,13 @@ expect_equal_to_reference(
                                    fun = function(x, weight = NULL) numeric(0), 
                                    row_vars = am, weight = 1
     )
-    ,"rds/table_summary_df0empty.rds"
+    ,"rds/table_summary_df0empty.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     cro_fun_df(mtcars %n_d% qc(vs, am) %>% set_var_lab("|") %>% as.list, 
                col_vars = mtcars$am, fun = colMeans)
-    ,"rds/table_summary_df1.rds"
+    ,"rds/table_summary_df1.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
@@ -117,25 +117,25 @@ expect_equal_to_reference(
 
         dtfrm(parameter = names(x), mean = colMeans(x))
     })
-    ,"rds/table_summary_df2.rds"
+    ,"rds/table_summary_df2.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     cro_fun_df(mtcars %n_d% qc(vs, am) %>% unvr, col_vars = mtcars$am, fun = colMeans
     )
-    ,"rds/table_summary_df3.rds"
+    ,"rds/table_summary_df3.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     cro_fun_df(mtcars %n_d% qc(vs, am), col_vars = mtcars$am,  fun = colMeans)
-    ,"rds/table_summary_df4.rds"
+    ,"rds/table_summary_df4.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     cro_fun_df(mtcars %n_d% qc(vs, am), col_vars = mtcars$am, row_vars = mtcars$vs,
                      fun = colMeans
                      )
-    ,"rds/table_summary_df5.rds"
+    ,"rds/table_summary_df5.rds",  update = FALSE
 )
 
 
@@ -144,7 +144,7 @@ expect_equal_to_reference(
                      row_vars = dtfrm("Total",mtcars$vs),
                      fun = colMeans
     )
-    ,"rds/table_summary_df5c.rds"
+    ,"rds/table_summary_df5c.rds",  update = FALSE
 )
 
 
@@ -153,7 +153,7 @@ expect_equal_to_reference(
                                            row_vars = vs,
                      fun = colMeans
     ))
-    ,"rds/table_summary_df5a.rds"
+    ,"rds/table_summary_df5a.rds",  update = FALSE
 )
 
 
@@ -162,7 +162,7 @@ expect_equal_to_reference(
                                            col_vars = am, 
                                                  fun = colMeans
     ))
-    ,"rds/table_summary_df5b.rds"
+    ,"rds/table_summary_df5b.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
@@ -170,7 +170,7 @@ expect_equal_to_reference(
                                            col_vars = list(total(1), am), 
                                            fun = colMeans
     )
-    ,"rds/table_summary_df5bb.rds"
+    ,"rds/table_summary_df5bb.rds",  update = FALSE
 )
 
 expect_identical(
@@ -223,7 +223,7 @@ expect_equal_to_reference(
                          
                      }
                      )
-    ,"rds/table_summary_df6.rds"
+    ,"rds/table_summary_df6.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
@@ -234,7 +234,7 @@ expect_equal_to_reference(
                          dtfrm(cor = res[,1], mean = means)
                      }
                      )
-    ,"rds/table_summary_df7.rds"
+    ,"rds/table_summary_df7.rds",  update = FALSE
 )
 
 
@@ -244,7 +244,7 @@ expect_equal_to_reference(
     cro_fun_df(mtcars %n_d% qc(vs, am) %>% unvr, col_vars = mtcars$am,
                      fun = colSums
                      )
-    ,"rds/table_summary_df9.rds"
+    ,"rds/table_summary_df9.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
@@ -253,14 +253,14 @@ expect_equal_to_reference(
                          if(is.null(weight)) weight = 1
                          colSums(x*weight)
                      }, weight = 2)
-    ,"rds/table_summary_df10.rds"
+    ,"rds/table_summary_df10.rds",  update = FALSE
 )
 
 
 expect_equal_to_reference(
     cro_fun_df(mtcars %n_d% c("cyl", "am")   , 
                col_vars = list("Total", mtcars$am), fun = colMeans),
-    "rds/table_summary_df11.rds"
+    "rds/table_summary_df11.rds",  update = FALSE
 )
 
 
@@ -269,7 +269,7 @@ expect_equal_to_reference(
                      col_vars = list("Total", unvr(mtcars$am)),
                      fun = colMeans
                      ),
-    "rds/table_summary_df12.rds"
+    "rds/table_summary_df12.rds",  update = FALSE
 )
 
 
@@ -287,44 +287,44 @@ context("table correlations")
 val_lab(mtcars$am) = val_lab(mtcars$am)[1:2] 
 expect_equal_to_reference(
     cro_pearson(mtcars %n_d% qc(vs, am), col_vars = mtcars$am)
-    ,"rds/table_cor_1.rds"
+    ,"rds/table_cor_1.rds",  update = FALSE
 )
 
 val_lab(mtcars$am) = val_lab(mtcars$am)[1:2] 
 expect_equal_to_reference(
     calc_cro_pearson(mtcars, ..[!perl("vs|am")], col_vars = am)
-    ,"rds/table_cor_1.rds"
+    ,"rds/table_cor_1.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     cro_spearman(mtcars %n_d% qc(vs, am), col_vars = mtcars$am)
-    ,"rds/table_cor_2.rds"
+    ,"rds/table_cor_2.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     calc_cro_spearman(mtcars, ..[!perl("vs|am")], col_vars = am)
-    ,"rds/table_cor_2.rds"
+    ,"rds/table_cor_2.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     mtcars %>% where(FALSE) %calc% cro_pearson(vars(!perl("vs|am")), col_vars = am)
-    ,"rds/table_cor_1a.rds"
+    ,"rds/table_cor_1a.rds",  update = FALSE
 )
 
 
 expect_equal_to_reference(
     mtcars %>% where(FALSE) %calc% cro_pearson(vars(!perl("vs|am")), col_vars = am)
-    ,"rds/table_cor_1a.rds"
+    ,"rds/table_cor_1a.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     cro_spearman(mtcars %n_d% qc(vs, am), col_vars = mtcars$am)
-    ,"rds/table_cor_2.rds"
+    ,"rds/table_cor_2.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     cro_spearman(mtcars %n_d% qc(vs, am), col_vars = mtcars$am, weight = 1)
-    ,"rds/table_cor_2.rds"
+    ,"rds/table_cor_2.rds",  update = FALSE
 )
 
 expect_identical(
@@ -362,11 +362,11 @@ set.seed(1)
 weight = runif(nrow(mtcars), 1,2)
 expect_equal_to_reference(
     cro_pearson(mtcars %>% except(vs, am), col_vars = mtcars$am, weight = weight)
-    ,"rds/table_cor_3.rds"
+    ,"rds/table_cor_3.rds",  update = FALSE
 )
 expect_equal_to_reference(
     cro_spearman(mtcars %>% except(vs, am), col_vars = mtcars$am, weight = weight)
-    ,"rds/table_cor_4.rds"
+    ,"rds/table_cor_4.rds",  update = FALSE
 )
 
 
@@ -382,35 +382,35 @@ dates = as.POSIXct(rep(paste0("2017-02-", 1:10), each = 10))
 measure = runif(length(dates), 1, 2)
 expect_equal_to_reference(
 cro_fun_df(measure, col_vars = list("Total"), row_vars = list(dates), fun = mean)
-,"rds/table_summary_df_dates1.rds"
+,"rds/table_summary_df_dates1.rds",  update = FALSE
 )
 expect_equal_to_reference(
     cro_fun_df(list(measure), col_vars = list(dates), fun = mean)
-,"rds/table_summary_df_dates2.rds"
+,"rds/table_summary_df_dates2.rds",  update = FALSE
 )
 var_lab(dates) = "Day"
 expect_equal_to_reference(
     cro_fun_df(list(measure), col_vars = list("Total"), row_vars = list(dates), fun = mean)
-,"rds/table_summary_df_dates3.rds"
+,"rds/table_summary_df_dates3.rds",  update = FALSE
 )
 expect_equal_to_reference(
     cro_fun_df(list(measure), col_vars = list(dates), fun = mean)
-,"rds/table_summary_df_dates4.rds"
+,"rds/table_summary_df_dates4.rds",  update = FALSE
 )
 
 context("cro_fun_df duplicated names")
 
 expect_equal_to_reference(
     calculate(mtcars, cro_mean(list(mpg, mpg, mpg, mpg), list(am))),
-    "rds/cro_fun_df_duplicated_names.rds"
+    "rds/cro_fun_df_duplicated_names.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     calc_cro_mean(mtcars, list(mpg, mpg, mpg, mpg), list(am)),
-    "rds/cro_fun_df_duplicated_names.rds"
+    "rds/cro_fun_df_duplicated_names.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     calculate(mtcars, cro_mean(list(mpg, mpg, mpg, mpg), list(am), weight = wt)),
-    "rds/cro_fun_df_duplicated_names_weighted.rds"
+    "rds/cro_fun_df_duplicated_names_weighted.rds",  update = FALSE
 )
