@@ -43,13 +43,19 @@ big = cbind(a_res, b_res)
 class(big) = union("category", class(big))
 
 expect_identical(calculate(product_test, mrset(a1_1 %to% a1_6)), a_res)
+expect_identical(calculate(product_test, mrset_f(a1_)), a_res)
+expect_identical(calculate(product_test, mrset_p("a1_")), a_res)
 expect_identical(calculate(product_test, mrset(as.matrix(a1_1 %to% a1_6))), unlab(a_res))
 expect_identical(calculate(product_test, mrset(a1_1 %to% a1_6, b1_1 %to% b1_6)), big)
+expect_identical(calculate(product_test, mrset_f(a1_, b1_)), big)
+expect_identical(calculate(product_test, mrset_p("^a1_\\d$", "^b1_\\d$")), big)
 big$b1_1 = unlab(big$b1_1)
 expect_identical(calculate(product_test, mrset(a1_1 %to% a1_6, as.matrix(b1_1 %to% b1_6))), big)
 expect_identical(calculate(product_test, mrset(a1_1)), setNames(a_res[,1, drop = FALSE], "a1_1"))
 var_lab(a_res$a1_1) = "New label"
 expect_identical(calculate(product_test, mrset(a1_1 %to% a1_6, label = "New label")), a_res)
+expect_identical(calculate(product_test, mrset_f(a1_, label = "New label")), a_res)
+expect_identical(calculate(product_test, mrset_p("a1_", label = "New label")), a_res)
 #########################
 context("mdset")
 
@@ -65,6 +71,8 @@ strange = a_res_dich
 if_val(a_res_dich) = 1:150>100 ~ NA
 if_val(strange) = 1:150>100 ~ 0
 expect_identical(mdset(strange), strange)
+expect_identical(calc(strange, mdset_f(v)), strange)
+expect_identical(calc(strange, mdset_p("v")), strange)
 a_res_dich = as.dichotomy(a_res)
 strange = a_res_dich
 if_val(strange) = c(0 ~ NA, 1 ~ 42)
@@ -92,3 +100,5 @@ for(each in seq_along(a_res_dich)){
 }
 
 expect_identical(mdset(a_res, label = "New label"),  a_res_dich)
+expect_identical(calc(a_res, mdset_f(v, label = "New label")),  a_res_dich)
+expect_identical(calc(a_res, mdset_p("v", label = "New label")),  a_res_dich)
