@@ -71,144 +71,144 @@ mtcars_table = cro_cpct(list(mtcars$cyl, mtcars$gear),
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none"),
-    "rds/signif_cpct1.rds")
+    "rds/signif_cpct1.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, inequality_sign = TRUE,  keep = "none"),
-    "rds/signif_cpct1_greater_sign.rds")
+    "rds/signif_cpct1_greater_sign.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none", subtable_marks = "less"),
-    "rds/signif_cpct1_less.rds")
+    "rds/signif_cpct1_less.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, inequality_sign = TRUE,
                       keep = "none", subtable_marks = "less"),
-    "rds/signif_cpct1_less_sign.rds")
+    "rds/signif_cpct1_less_sign.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none", subtable_marks = "both"),
-    "rds/signif_cpct1_both.rds")
+    "rds/signif_cpct1_both.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, inequality_sign = FALSE,
                       keep = "none", subtable_marks = "both"),
-    "rds/signif_cpct1_both_no_signs.rds")
+    "rds/signif_cpct1_both_no_signs.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none", na_as_zero = TRUE),
-    "rds/signif_cpct2.rds")
+    "rds/signif_cpct2.rds",  update = FALSE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table,
                       keep = "none",
                       sig_labels = paste0("(",letters, ")")),
-    "rds/signif_cpct3.rds")
+    "rds/signif_cpct3.rds",  update = FALSE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table,
                       keep = "none",
                       sig_labels = NULL),
-    "rds/signif_cpct4.rds")
+    "rds/signif_cpct4.rds",  update = FALSE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none",
                       compare_type = c("subtable", "first_column")),
-    "rds/signif_cpct5.rds")
+    "rds/signif_cpct5.rds",  update = FALSE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none",
                       compare_type = c("subtable", "adjusted_first_column")),
-    "rds/signif_cpct6.rds")
+    "rds/signif_cpct6.rds",  update = FALSE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none",
                       compare_type = c("subtable", "adjusted_first_column"),
                       na_as_zero = TRUE
                       ),
-    "rds/signif_cpct7.rds")
+    "rds/signif_cpct7.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none"
                       , compare_type = c("previous_column")),
-    "rds/signif_cpct8.rds")
+    "rds/signif_cpct8.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "none",
                       compare_type = c("previous_column"),
                       na_as_zero = TRUE),
-    "rds/signif_cpct9.rds")
+    "rds/signif_cpct9.rds",  update = FALSE)
 
 #####################
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "bases"),
-    "rds/signif_cpct10.rds")
+    "rds/signif_cpct10.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table),
-    "rds/signif_cpct11.rds")
+    "rds/signif_cpct11.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table),
-    "rds/signif_cpct11.rds")
+    "rds/signif_cpct11.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, delta_cpct = 50),
-    "rds/signif_cpct11_delta.rds")
+    "rds/signif_cpct11_delta.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, keep = "percent"),
-    "rds/signif_cpct12.rds")
+    "rds/signif_cpct12.rds",  update = FALSE)
 
 
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       compare_type = c("subtable", "first_column")),
-    "rds/signif_cpct13.rds")
+    "rds/signif_cpct13.rds",  update = FALSE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       compare_type = c("subtable", "adjusted_first_column")),
-    "rds/signif_cpct14.rds")
+    "rds/signif_cpct14.rds",  update = FALSE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table,
                       compare_type = c("subtable", "adjusted_first_column"),
                       na_as_zero = TRUE
     ),
-    "rds/signif_cpct15.rds")
+    "rds/signif_cpct15.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       compare_type = c("previous_column")),
-    "rds/signif_cpct16.rds")
+    "rds/signif_cpct16.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       delta_cpct = 65,
                       compare_type = c("previous_column")),
-    "rds/signif_cpct16_delta.rds")
+    "rds/signif_cpct16_delta.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       delta_cpct = 65,
                       na_as_zero = TRUE,
                       compare_type = c("previous_column")),
-    "rds/signif_cpct16_delta2.rds")
+    "rds/signif_cpct16_delta2.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       compare_type = c("previous_column"), 
                       na_as_zero = TRUE),
-    "rds/signif_cpct17.rds")
+    "rds/signif_cpct17.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       compare_type = c("previous_column"), 
                       na_as_zero = TRUE,
                       min_base = 14),
-    "rds/signif_cpct18.rds")
+    "rds/signif_cpct18.rds",  update = FALSE)
 
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       na_as_zero = TRUE,
                       sig_level = 0.9),
-    "rds/signif_cpct19.rds")
+    "rds/signif_cpct19.rds",  update = FALSE)
 
 #####################
 mtcars_table2 = cro_cpct(list(mtcars$vs, mtcars$am),
@@ -222,7 +222,7 @@ expect_equal_to_reference(
                       bonferroni = FALSE,
                       na_as_zero = FALSE, 
                       sig_level = 0.004),
-    "rds/signif_cpct20.rds")
+    "rds/signif_cpct20.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table2, 
@@ -230,7 +230,7 @@ expect_equal_to_reference(
                                        "previous_column",
                                        "subtable"),
                       sig_level = 0.1),
-    "rds/signif_cpct20greater.rds")
+    "rds/signif_cpct20greater.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table2, 
@@ -239,7 +239,7 @@ expect_equal_to_reference(
                                        "subtable"),
                       subtable_marks = "less",
                       sig_level = 0.1),
-    "rds/signif_cpct20less.rds")
+    "rds/signif_cpct20less.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table2, 
@@ -248,7 +248,7 @@ expect_equal_to_reference(
                                        "subtable"),
                       subtable_marks = "both",
                       sig_level = 0.1),
-    "rds/signif_cpct20both.rds")
+    "rds/signif_cpct20both.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table2, 
@@ -258,7 +258,7 @@ expect_equal_to_reference(
                       bonferroni = TRUE,
                       na_as_zero = FALSE, 
                       sig_level = 0.004),
-    "rds/signif_cpct20boneferrony.rds")
+    "rds/signif_cpct20boneferrony.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table2, 
@@ -268,7 +268,7 @@ expect_equal_to_reference(
                       bonferroni = FALSE,
                       na_as_zero = FALSE, 
                       sig_level = 0.002),
-    "rds/signif_cpct20_2.rds")
+    "rds/signif_cpct20_2.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table2, 
@@ -278,7 +278,7 @@ expect_equal_to_reference(
                       bonferroni = TRUE,
                       na_as_zero = FALSE, 
                       sig_level = 0.002),
-    "rds/signif_cpct20boneferrony_2.rds")
+    "rds/signif_cpct20boneferrony_2.rds",  update = FALSE)
 
 #####################
 
@@ -286,14 +286,14 @@ expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       compare_type = c("subtable", "first_column"), 
                       digits = 2),
-    "rds/signif_cpct21.rds")
+    "rds/signif_cpct21.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table, 
                       compare_type = c("subtable", "first_column"), 
                       delta_cpct = 30,
                       digits = 2),
-    "rds/signif_cpct21_delta.rds")
+    "rds/signif_cpct21_delta.rds",  update = FALSE)
 
 expect_error(
     significance_cpct(mtcars_table, 
@@ -310,7 +310,7 @@ expect_equal_to_reference(
                                        "previous_column",
                                        "subtable"), 
                       total_marker = "@"),
-    "rds/signif_cpct22.rds")
+    "rds/signif_cpct22.rds",  update = FALSE)
 
 expect_error(
 significance_cpct(mtcars_table2, 
@@ -332,7 +332,7 @@ significance_cpct(mtcars_table3,
                   compare_type = c("first_column", 
                                    "previous_column",
                                    "subtable")),
-"rds/signif_cpct23.rds")
+"rds/signif_cpct23.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3, 
@@ -340,7 +340,7 @@ expect_equal_to_reference(
                                        "previous_column",
                                        "subtable"), 
                       total_row = 2),
-    "rds/signif_cpct24.rds")
+    "rds/signif_cpct24.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3, 
@@ -348,7 +348,7 @@ expect_equal_to_reference(
                                        "previous_column",
                                        "subtable"), 
                       total_row = "#Total cases"),
-    "rds/signif_cpct24.rds")
+    "rds/signif_cpct24.rds",  update = FALSE)
 
 mtcars_table3 = cro_cpct(list(mtcars$cyl, mtcars$gear),
                          list(total(), mtcars$vs, mtcars$am),
@@ -357,11 +357,11 @@ mtcars_table3 = cro_cpct(list(mtcars$cyl, mtcars$gear),
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3, keep = "none"),
-    "rds/signif_cpct1a.rds")
+    "rds/signif_cpct1a.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3, keep = "none", sig_labels = "a"),
-    "rds/signif_cpct25.rds")
+    "rds/signif_cpct25.rds",  update = FALSE)
 
 mtcars_table3 = cro_cpct(list(mtcars$cyl, mtcars$gear),
                          unvr(list(total(), mtcars$vs, mtcars$am)),
@@ -372,18 +372,18 @@ expect_equal_to_reference(
     significance_cpct(mtcars_table3,
                       compare_type = c("previous_column", "subtable"),
                       sig_labels = "a"),
-    "rds/signif_cpct26.rds")
+    "rds/signif_cpct26.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3,
                       compare_type = c("previous_column", "subtable"),
                       sig_labels = NULL),
-    "rds/signif_cpct26a.rds")
+    "rds/signif_cpct26a.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3,
                       compare_type = c("previous_column", "subtable")),
-    "rds/signif_cpct27.rds")
+    "rds/signif_cpct27.rds",  update = FALSE)
 
 mtcars_table3 = cro_cpct(list(mtcars$cyl),
                          unvr(list(total(), mtcars$vs, mtcars$am)),
@@ -393,14 +393,14 @@ mtcars_table3 = cro_cpct(list(mtcars$cyl),
 expect_equal_to_reference(
     significance_cpct(mtcars_table3,
                       compare_type = c("previous_column", "subtable")),
-    "rds/signif_cpct28.rds")
+    "rds/signif_cpct28.rds",  update = FALSE)
 
 colnames(mtcars_table3) = rep("", NCOL(mtcars_table3))
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3,
                       compare_type = c("previous_column", "subtable")),
-    "rds/signif_cpct29.rds")
+    "rds/signif_cpct29.rds",  update = FALSE)
 
 expect_error(
     significance_cpct(mtcars_table3,
@@ -415,57 +415,57 @@ mtcars_table3 = cro_cpct(list(mtcars$cyl),
 expect_equal_to_reference(
     significance_cpct(mtcars_table3[ ,1],
                       compare_type = c("first_column", "subtable")),
-    "rds/signif_cpct30.rds")
+    "rds/signif_cpct30.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3[ ,1:2],
                       compare_type = c("first_column", "subtable")),
-    "rds/signif_cpct31.rds")
+    "rds/signif_cpct31.rds",  update = FALSE)
 
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3[ ,1:3],
                       compare_type = c("first_column", "subtable")),
-    "rds/signif_cpct32.rds")
+    "rds/signif_cpct32.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table3[ ,c(1:2,4,5)],
                       compare_type = c("first_column", "subtable")),
-    "rds/signif_cpct33.rds")
+    "rds/signif_cpct33.rds",  update = FALSE)
 
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table[ ,1]),
-    "rds/signif_cpct34.rds")
+    "rds/signif_cpct34.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table[ ,1],
                       subtable_marks = "both"
                       ),
-    "rds/signif_cpct34.rds")
+    "rds/signif_cpct34.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table[ ,1],
                       compare_type = c("previous", "first", "subtable"),
                       subtable_marks = "both"
     ),
-    "rds/signif_cpct34.rds")
+    "rds/signif_cpct34.rds",  update = FALSE)
 
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table[ ,1],
                       keep = "bases"),
-    "rds/signif_cpct34.rds")
+    "rds/signif_cpct34.rds",  update = FALSE)
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table[ ,1],
                       keep = "none"),
-    "rds/signif_cpct35.rds")
+    "rds/signif_cpct35.rds",  update = FALSE)
 
 if(sessionInfo()$R.version$arch!="i386"){
     expect_equal_to_reference(
         significance_cpct(cro_cpct(NA)),
-        "rds/signif_cpct36.rds")
+        "rds/signif_cpct36.rds",  update = FALSE)
 }
 
 mtcars_table4 = mtcars %calc% cro_cpct(list(cyl, gear),
@@ -475,17 +475,17 @@ mtcars_table4 = mtcars %calc% cro_cpct(list(cyl, gear),
 
 expect_equal_to_reference(
     significance_cpct(mtcars_table4, compare_type = c("first_column", "subtable")),
-    "rds/signif_cpct37.rds")
+    "rds/signif_cpct37.rds",  update = FALSE)
 
 colnames(mtcars_table4) = gsub("ss", "s\ns", colnames(mtcars_table4), perl = TRUE)
 colnames(mtcars_table4) = gsub("aight", "ai\rght", colnames(mtcars_table4), perl = TRUE)
 expect_equal_to_reference(
     significance_cpct(mtcars_table4, compare_type = c("first_column", "subtable")),
-    "rds/signif_cpct37b.rds")
+    "rds/signif_cpct37b.rds",  update = FALSE)
 
 mtcars_table5 = cro_cpct(list(mtcars$cyl, mtcars$gear),
                         unvr(list(total(), mtcars$vs, mtcars$am)))
 
 
 expect_equal_to_reference(
-    significance_cpct(mtcars_table5), "rds/signif_cpct38.rds")
\ No newline at end of file
+    significance_cpct(mtcars_table5), "rds/signif_cpct38.rds",  update = FALSE)
\ No newline at end of file
